Crate p2wsh_utxo

Crate p2wsh_utxo 

Structs

UTXO
UTXO represents an Unspent transaction Output. id or amount might not be filled in if the results were generated with minimized data.
UTXOResults
UTXOResults holds a vector of UTXOs that represent P2WSH bitcoin transactions that have not been spent yet.

Constants

MAX_SCID_VOUT_INDEX
Maximum vout index that can be used in a short_channel_id. This value is based on the 2-bytes available for the vout index.