Structs
- UTXO
- UTXO represents an Unspent transaction Output.
idoramountmight not be filled in if the results were generated with minimized data. - UTXO
Results - UTXOResults holds a vector of
UTXOs that represent P2WSH bitcoin transactions that have not been spent yet.
Constants
- MAX_
SCID_ VOUT_ INDEX - Maximum vout index that can be used in a
short_channel_id. This value is based on the 2-bytes available for the vout index.